.. include:: ../refs.rst

.. _management:

==========
Management
==========

.. autoclass:: django_typer.management.TyperCommand
    :members:
    :special-members: __call__

.. automodule:: django_typer.management
   :members:
   :exclude-members: Typer, CommandGroup, TyperCommand, Context, CommandNode
   :show-inheritance:

.. autoclass:: django_typer.management.Context
    :members:

.. autoclass:: django_typer.management.Typer
    :members:

.. autoclass:: django_typer.management.TyperParser
    :members:

.. autoclass:: django_typer.management.CommandNode
    :members:

.. autoclass:: django_typer.management.TyperCommandMeta

